@@ -19,7 +19,6 @@ else:
     from BaseHTTPServer import BaseHTTPRequestHandler
     from StringIO import StringIO
 
-import asyncore
 import hashlib
 import base64
 import socket
@@ -29,6 +28,8 @@ import codecs
 import logging
 from collections import deque
 
+from . import asyncore
+
 __all__ = ['WebSocket', 'AsyncWebSocketHandler']
 
 logger = logging.getLogger(__name__)
