@@ -32,33 +32,27 @@ the Standard Library and the echo WebSocket on ``'/ws'`` path.
 """
 
 from __future__ import absolute_import
-import asyncore
+
 import logging
 import select
 import socket
-import sys
 from errno import EINTR
 from io import BytesIO
 from shutil import copyfileobj
 from tempfile import TemporaryFile
 from wsgiref.simple_server import WSGIServer, ServerHandler, WSGIRequestHandler
+
+from . import asyncore
 from .SimpleWebSocketServer import AsyncWebSocketHandler
 
 __all__ = ['AsyncWsgiHandler', 'AsyncWebSocketHandler', 'AsyncWsgiServer',
             'make_server']
 
-__version__ = '0.0.10'
+__version__ = '0.0.11'
 
 logger = logging.getLogger('asyncore_wsgi')
 
 
-def iteritems(dct):
-    """Get iterator for dict items"""
-    if sys.version_info[0] == 2:
-        return dct.iteritems()
-    return dct.items()
-
-
 def epoll_poller(timeout=0.0, map=None):
     """
     A poller which uses epoll(), supported on Linux 2.5.44 and newer
@@ -70,7 +64,7 @@ def epoll_poller(timeout=0.0, map=None):
         map = asyncore.socket_map
     pollster = select.epoll()
     if map:
-        for fd, obj in iteritems(map):
+        for fd, obj in map.items():
             flags = 0
             if obj.readable():
                 flags |= select.POLLIN | select.POLLPRI
@@ -124,6 +118,11 @@ class AsyncServerHandler(ServerHandler):
         """Get WSGI response iterator for sending in handle_write"""
         self.iterator = iter(self.result)
 
+    def close(self):
+        super().close()
+        if hasattr(self.stdin, 'close'):
+            self.stdin.close()
+
 
 class AsyncWsgiHandler(asyncore.dispatcher, WSGIRequestHandler):
     """
@@ -183,22 +182,17 @@ class AsyncWsgiHandler(asyncore.dispatcher, WSGIRequestHandler):
             self._switch_to_websocket()
             return
         self._input_stream = BytesIO()
-        if self.command.lower() in ('post', 'put', 'patch'):
-            cont_length = self.headers.get('content-length')
-            if cont_length is None:
-                self.send_error(411)
+        cont_length = self.headers.get('content-length')
+        if cont_length is not None:
+            cont_length = int(cont_length)
+            if cont_length > self.max_input_content_length:
+                self.send_error(413)
                 self.handle_close()
                 return
-            else:
-                cont_length = int(cont_length)
-                if cont_length > self.max_input_content_length:
-                    self.send_error(413)
-                    self.handle_close()
-                    return
-                elif cont_length > self.max_input_in_memory:
-                    self._input_stream = TemporaryFile()
-                copyfileobj(self.rfile, self._input_stream)
-                self._input_stream.seek(0)
+            elif cont_length > self.max_input_in_memory:
+                self._input_stream = TemporaryFile()
+            copyfileobj(self.rfile, self._input_stream)
+            self._input_stream.seek(0)
         self._server_handler = AsyncServerHandler(
             self._input_stream, self.wfile, self.get_stderr(),
             self.get_environ())
@@ -249,7 +243,7 @@ class AsyncWsgiHandler(asyncore.dispatcher, WSGIRequestHandler):
             self._can_write = True
 
     def handle_error(self):
-        logger.exception('Exception in {}!'.format(repr(self)))
+        logger.exception('Error in %s!', repr(self))
         self.handle_close()
 
     def close(self):
@@ -296,7 +290,7 @@ class AsyncWsgiServer(asyncore.dispatcher, WSGIServer):
                 self.RequestHandlerClass(pair[0], pair[1], self, self._map)
 
     def handle_error(self, *args, **kwargs):
-        logger.exception('Exception in {}!'.format(repr(self)))
+        logger.exception('Error in %s!', repr(self))
         self.handle_close()
 
     def poll_once(self, timeout=0.0):
@@ -324,9 +318,8 @@ class AsyncWsgiServer(asyncore.dispatcher, WSGIServer):
         :param poll_interval: polling timeout
         :return:
         """
-        logger.info('Starting server on {}:{}...'.format(
-            self.server_name, self.server_port)
-        )
+        logger.info('Starting server on %s:%s...',
+                    self.server_name, self.server_port)
         while True:
             try:
                 self.poll_once(poll_interval)
